<?php

namespace Coming_Soon_Widgets\Widgets;

use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Coming_Soon extends Widget_Base
{
  public function get_name()
  {
    return 'Coming_Soon';
  }

  public function get_title()
  {
    return esc_html__('Coming Soon', 'coming-soon-widgets');
  }

  public function get_icon()
  {
    return 'eicon-image';
  }

  public function get_categories()
  {
    return ['themesflat_addons'];
  }

  public function get_script_depends()
  {
    return ['coming_soon_widgets_script'];
  }

  public function get_style_depends()
  {
    return ['font-awesome', 'coming_soon_widgets_style'];
  }

  protected function register_controls()
  {
    //add text control
    $this->start_controls_section('coming_soon_value_default_widgets_logo',
      [
        'label' => esc_html__('Logo', 'coming-soon-widgets')
      ]
    );

    $this->add_control('coming_soons_logo',
      [
        'label' => esc_html__('Choose logo', 'coming-soon-widgets'),
        'type' => Controls_Manager::MEDIA,
        'default' => [
          'url' => URL_PLUGIN_THEMESFLAT_ELEMENTOR . "/assets/img/logo.png",
        ],
        'label_block' => true
      ]
    );

    $this->end_controls_section();
    //end text control

    //add text control
    $this->start_controls_section('coming_soon_value_default_widgets_txt',
      [
        'label' => esc_html__('Content', 'coming-soon-widgets')
      ]
    );

    $this->add_control('coming_soons_title',
      [
        'label' => esc_html__('Title', 'coming-soon-widgets'),
        'type' => Controls_Manager::TEXT,
        'default' => 'COMING SOON',
        'label_block' => true
      ]
    );

    $this->add_control('coming_soons_subtitle',
      [
        'label' => esc_html__('Subtitle', 'coming-soon-widgets'),
        'type' => Controls_Manager::WYSIWYG,
        'default' => '<p>Our website is under construction, follow us for update now!</p>',
        'label_block' => true,
        'dynamic' => [
          'active' => true,
        ],
      ]
    );

    $this->add_control('coming_soons_txt_copyright',
      [
        'label' => esc_html__('Copyright', 'coming-soon-widgets'),
        'type' => Controls_Manager::WYSIWYG,
        'default' => '@ 2019 Coming Soon Template. Designed by <a href="#">Themesflat</a>',
        'label_block' => true,
        'dynamic' => [
          'active' => true,
        ],
      ]
    );

    $this->end_controls_section();
    //end text control

    //add text control
    $this->start_controls_section('coming_soon_value_default_widgets_date',
      [
        'label' => esc_html__('Date', 'coming-soon-widgets')
      ]
    );

    $date = date_create(date("Y/m/d"));
    date_add($date, date_interval_create_from_date_string("40 days"));
    $this->add_control('coming_soons_date',
      [
        'label' => esc_html__('Date', 'coming-soon-widgets'),
        'type' => Controls_Manager::DATE_TIME,
        'default' => date_format($date, "Y-m-d") . ' 23:59:59',
      ]
    );

    $this->add_control('coming_soons_days',
      [
        'label' => esc_html__('Change text Days', 'coming-soon-widgets'),
        'type' => Controls_Manager::TEXT,
        'default' => 'DAYS',
      ]
    );

    $this->add_control('coming_soons_hours',
      [
        'label' => esc_html__('Change text Hours', 'coming-soon-widgets'),
        'type' => Controls_Manager::TEXT,
        'default' => 'HOURS',
      ]
    );

    $this->add_control('coming_soons_minutes',
      [
        'label' => esc_html__('Change text Minutes', 'coming-soon-widgets'),
        'type' => Controls_Manager::TEXT,
        'default' => 'MINUTES',
      ]
    );

    $this->add_control('coming_soons_seconds',
      [
        'label' => esc_html__('Change text Seconds', 'coming-soon-widgets'),
        'type' => Controls_Manager::TEXT,
        'default' => 'SECONDS',
      ]
    );

    $this->end_controls_section();
    //end text control

    //Layout
    $this->start_controls_section(
      'coming_soon_layout',
      [
        'label' => __('Layout', 'coming-soon-widgets'),
        'tab' => Controls_Manager::TAB_LAYOUT,
      ]
    );

    $this->add_control('coming_soons_styles',
      [
        'label' => esc_html__('Choose layout', 'coming-soon-widgets'),
        'type' => Controls_Manager::SELECT,
        'options' => [
          '1' => __('Default', 'coming-soon-widgets'),
          '2' => __('Demo 2', 'coming-soon-widgets'),
          '3' => __('Demo 3', 'coming-soon-widgets'),
          '4' => __('Demo 4', 'coming-soon-widgets'),
        ],
        'default' => '1',
        'label_block' => true
      ]
    );

    $repeater = new \Elementor\Repeater();

    //Images
    $repeater->add_control('coming_soons_demo1_image',
      [
        'label' => esc_html__('Choose image', 'coming-soon-widgets'),
        'type' => Controls_Manager::MEDIA,
        'default' => [
          'url' => URL_PLUGIN_THEMESFLAT_ELEMENTOR . "/assets/img/bg01.jpg",
        ],
        'label_block' => true
      ]
    );

    $this->add_control('coming_soons_list_images',
      [
        'label' => esc_html__('Images', 'coming-soon-widgets'),
        'type' => Controls_Manager::REPEATER,
        'fields' => array_values($repeater->get_controls()),
      ]
    );

    //Socials
    $repeater1 = new \Elementor\Repeater();
    $repeater1->add_control('coming_soons_social',
      [
        'label' => esc_html__('Icon', 'coming-soon-widgets'),
        'type' => Controls_Manager::ICON,
        'label_block' => true,
        'default' => 'fa fa-facebook'
      ]
    );
    $repeater1->add_control('coming_soons_link',
      [
        'label' => esc_html__('Link', 'coming-soon-widgets'),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '#'
      ]
    );

    $this->add_control('coming_soons_socials',
      [
        'label' => esc_html__('Socials', 'coming-soon-widgets'),
        'type' => Controls_Manager::REPEATER,
        'fields' => array_values($repeater1->get_controls()),
        'prevent_empty' => false,
      ]
    );

    $this->end_controls_section();

    // Style
    $this->start_controls_section(
      'section_style',
      [
        'label' => __('Change size', 'coming-soon-widgets'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_responsive_control(
      'coming_soons_logo_size',
      [
        'label' => __('Size logo', 'coming-soon-widgets'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 120,
        ],
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 600,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .c-countdown .c-countdown__logo' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_responsive_control(
      'coming_soons_title_size',
      [
        'label' => __('Font size title', 'coming-soon-widgets'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 50,
        ],
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 600,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .c-countdown h3' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_responsive_control(
      'coming_soons_subtitle_size',
      [
        'label' => __('Font size subtitle', 'coming-soon-widgets'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 25,
        ],
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 600,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .c-countdown p' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_responsive_control(
      'coming_soons_copyright_size',
      [
        'label' => __('Font size copyright', 'coming-soon-widgets'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 16,
        ],
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 600,
          ],
        ],
        'selectors' => [
          '.c-countdown .c-countdown__copy' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->add_responsive_control(
      'coming_soons_date_size',
      [
        'label' => __('Font size date', 'coming-soon-widgets'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 80,
        ],
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 600,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .c-countdown__number' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_responsive_control(
      'coming_soons_txt_size',
      [
        'label' => __('Font size text', 'coming-soon-widgets'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 18,
        ],
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 600,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .c-countdown__txt' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    //end text control
    $this->end_controls_section();

    // Style
    $this->start_controls_section(
      'distance_style',
      [
        'label' => __('Change distance', 'coming-soon-widgets'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_responsive_control(
      'coming_soons_title_margin',
      [
        'label' => __('Margin title', 'coming-soon-widgets'),
        'type' => Controls_Manager::DIMENSIONS,
        'default' => [
          'top' => '0',
          'right' => '',
          'bottom' => '22',
          'left' => '',
        ],
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 600,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .c-countdown h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->add_responsive_control(
      'coming_soons_subtitle_margin',
      [
        'label' => __('Padding subtitle', 'coming-soon-widgets'),
        'type' => Controls_Manager::DIMENSIONS,
        'default' => [
          'top' => '0',
          'right' => '',
          'bottom' => '67',
          'left' => '',
        ],
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 600,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .c-countdown p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    //end text control
    $this->end_controls_section();

    // Style
    //add text control
    $this->start_controls_section('coming_soon_demo1_widgets',
      [
        'label' => esc_html__('Change background color image', 'coming-soon-widgets'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control('coming_soons_demo1_color1',
      [
        'label' => esc_html__('Color 1', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => 'rgba(170, 7, 107, 0.9)',
        'label_block' => true,
      ]
    );

    $this->add_control('coming_soons_demo1_color2',
      [
        'label' => esc_html__('Color 2', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => 'rgba(97, 4, 95, 0.9)',
        'label_block' => true,
      ]
    );
    //end text control
    $this->end_controls_section();

    $this->start_controls_section(
      'colors_style',
      [
        'label' => __('Change colors', 'coming-soon-widgets'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control('coming_soons_demo1_color_title',
      [
        'label' => esc_html__('Title', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff',
        'label_block' => true,
        'selectors' => [
          '{{WRAPPER}} .c-countdown h3' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control('coming_soons_demo1_color_txt',
      [
        'label' => esc_html__('Subtitle', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff',
        'label_block' => true,
        'selectors' => [
          '{{WRAPPER}} .c-countdown p' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control('coming_soons_demo1_color_copyright',
      [
        'label' => esc_html__('Copyright', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff',
        'label_block' => true,
        'selectors' => [
          '{{WRAPPER}} .c-countdown .c-countdown__copy, {{WRAPPER}} .c-countdown .c-countdown__copy a' => 'color: {{VALUE}};',
          '{{WRAPPER}} .c-countdown .c-countdown__copy a:before' => 'background-color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control('coming_soons_demo1_color_number',
      [
        'label' => esc_html__('Text number', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff',
        'label_block' => true,
        'selectors' => [
          '{{WRAPPER}} .c-countdown__number' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control('coming_soons_demo1_color_txt_date',
      [
        'label' => esc_html__('Text date', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff',
        'label_block' => true,
        'selectors' => [
          '{{WRAPPER}} .c-countdown .c-countdown__txt' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control('coming_soons_demo1_color_socials',
      [
        'label' => esc_html__('Socials', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff',
        'label_block' => true,
        'selectors' => [
          '{{WRAPPER}} .c-countdown .c-countdown__socials a' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control('coming_soons_demo1_bgc_date',
      [
        'label' => esc_html__('Background date', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'label_block' => true,
        'selectors' => [
          '{{WRAPPER}} .c-countdown .c-countdown__item' => 'background-color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control('coming_soons_demo1_bdc_number',
      [
        'label' => esc_html__('Border date (Style 3)', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => 'rgba(255,255,255,.5)',
        'label_block' => true,
        'selectors' => [
          '{{WRAPPER}} .c-countdown.c-countdown--3 .c-countdown__item:before' => 'border-color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control('coming_soons_demo1_color_line',
      [
        'label' => esc_html__('Line (Smartphone)', 'coming-soon-widgets'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff',
        'label_block' => true
      ]
    );

    $this->end_controls_section();
  }

  protected function render($instance = [])
  {
    $settings = $this->get_settings_for_display();
    $idE = '.elementor-element-' . esc_attr($this->get_id());
    $title = $settings['coming_soons_title'];
    $subtitle = $settings['coming_soons_subtitle'];
    $logo = $settings['coming_soons_logo'];
    $images = $settings['coming_soons_list_images'];
    $socials = $settings['coming_soons_socials'];
    $copyright = $settings['coming_soons_txt_copyright'];
    ?>
    <div class="c-countdown c-countdown--<?php echo esc_attr($settings['coming_soons_styles']); ?>"
         data-time="<?php echo esc_attr($settings['coming_soons_date']); ?>"
         data-days="<?php echo esc_attr($settings['coming_soons_days']); ?>"
         data-hours="<?php echo esc_attr($settings['coming_soons_hours']); ?>"
         data-minutes="<?php echo esc_attr($settings['coming_soons_minutes']); ?>"
         data-seconds="<?php echo esc_attr($settings['coming_soons_seconds']); ?>">

      <?php if ($images) : ?>
        <div class="c-countdown__img">

          <?php foreach ($images as $item) { ?>
            <img src="<?php echo esc_html($item['coming_soons_demo1_image']['url']); ?>" alt=""/>
          <?php } ?>

        </div>
      <?php endif; ?>

      <?php if (esc_attr($settings['coming_soons_styles']) == 4) : ?>
        <div class="c-countdown__time"></div>
      <?php endif; ?>

      <div class="c-countdown__content">

        <?php if ($logo) : ?>
          <div class="c-countdown__logo"><a href="#"><img src="<?php echo esc_html($logo['url']); ?>" alt=""></a>
          </div>
        <?php endif; ?>

        <?php if ($title) : ?>
          <h3><?php echo esc_attr($title); ?></h3>
        <?php endif; ?>

        <?php if ($subtitle) :
          $editor_content = $this->parse_text_editor($subtitle);
          ?>
          <?php echo $editor_content; ?>
        <?php endif; ?>

        <?php
        if (esc_attr($settings['coming_soons_styles']) != 4) : ?>

          <div class="c-countdown__time"></div>

        <?php endif; ?>
      </div>

      <?php if ($socials) : ?>
        <div class="c-countdown__socials">

          <?php foreach ($socials as $item) { ?>
            <a href="<?php echo esc_url($item['coming_soons_link']); ?>"><i
                class="<?php echo esc_attr($item['coming_soons_social']); ?>"></i></a>
          <?php } ?>

        </div>
      <?php endif; ?>

      <?php if ($copyright) :
        $editor_content = $this->parse_text_editor($copyright);
        ?>
        <div class="c-countdown__copy"><?php echo $editor_content; ?></div>
      <?php endif; ?>

    </div>
    <style>
      @media only screen and (max-width: 767px) {
      <?php echo $idE; ?> .c-countdown__item:before {
        background-color: <?php echo esc_attr($settings['coming_soons_demo1_color_line']); ?>;
      }
      }

      <?php echo $idE; ?>
      .c-countdown__img:before {
        background: -webkit-linear-gradient(bottom, <?php echo esc_attr($settings['coming_soons_demo1_color1']); ?>, <?php echo esc_attr($settings['coming_soons_demo1_color2']); ?>);
        background: -webkit-gradient(linear, left bottom, left top, from(<?php echo esc_attr($settings['coming_soons_demo1_color1']); ?>), to(<?php echo esc_attr($settings['coming_soons_demo1_color2']); ?>));
        background: linear-gradient(bottom, <?php echo esc_attr($settings['coming_soons_demo1_color1']); ?>, <?php echo esc_attr($settings['coming_soons_demo1_color2']); ?>);
      }
    </style>

  <?php }
}